==> FHLBBS-4.2.tgz: wbbs/rungif.c <==
#include "cgic.h"
#define GIFNUM "/home/bbs/etc/maingifnum"
#define GIFHOME "/home/fhl"
#define BBSHOME "/home/bbs"
int cgiMain() {
    char genbuf[4096],location[128];
    int i;
    FILE *fp;
    int maxnum;
    int gifnum;
    int outmode; /* 0= gif , 1=goto */
		//srand(time(0));
               if (fp = fopen(GIFNUM, "r"))
               {
                fgets(genbuf,127 , fp);
                fclose(fp);
                maxnum = atoi(genbuf);
                if (maxnum <= 0)
                  maxnum = 20;              /* wwܦh 20 iʺAݪO */ 
               } else maxnum=20;
		/**** TwƦr *****/
		cgiFormInteger("GNUM",&gifnum,0);
	        gifnum=(gifnum%maxnum)+1;
		/***** ݬݿXk ***/
		cgiFormInteger("MODE",&outmode,0);
	        if (outmode) //sih
		{
	               sprintf(genbuf,BBSHOME "/man/www_manage/location.html");
               		if (fp = fopen(genbuf, "r"))
               		{
				for (i=0;i<gifnum;i++) fgets(genbuf,255,fp);
				sscanf(genbuf,"%s",location);
                 		fclose(fp);
				cgiHeaderLocation(location);
               		} else
               		{
                 	 	cgiHeaderContentType("text/html");
                    		fprintf(cgiOut,"S%sɮ",genbuf);
               		}
		}
		else //Xgif
	        {	
               	  sprintf(genbuf,GIFHOME "/mikehsyu/WWW/main/%03d.gif",gifnum);
                 	cgiHeaderContentType("image/gif");
               		if (fp = fopen(genbuf, "r"))
               		{
                 		while (i=fread(genbuf,1,4096, fp)) 
				fwrite(genbuf,1,i,cgiOut);
                 		fclose(fp);
               		} else
               		{
                    		fprintf(cgiOut,"S%sɮ",genbuf);
               		}
		}
               
}

==> FHLBBS-5.3.tgz: wbbs/rungif.c <==
#include "cgic.h"
#define GIFNUM "/home/WWW/data/ad_pic/maingifnum"
#define GIFHOME "/home/WWW/data/ad_pic"
#define BBSHOME "/home/WWW/data/ad_pic"
int cgiMain() {
    char genbuf[4096],location[128];
    int i;
    FILE *fp;
    int maxnum;
    int gifnum;
    int outmode; /* 0= gif , 1=goto */
		//srand(time(0));
               if (fp = fopen(GIFNUM, "r"))
               {
                fgets(genbuf,127 , fp);
                fclose(fp);
                maxnum = atoi(genbuf);
                if (maxnum <= 0)
                  maxnum = 20;              /* wwܦh 20 iʺAݪO */ 
               } else maxnum=20;
		/**** TwƦr *****/
		cgiFormInteger("GNUM",&gifnum,0);
	        gifnum=(gifnum%maxnum)+1;
		/***** ݬݿXk ***/
		cgiFormInteger("MODE",&outmode,0);
	        if (outmode) //sih
		{
	              //sprintf(genbuf,BBSHOME "/man/www_manage/location.html");
	               sprintf(genbuf,BBSHOME "/location.html");
               		if (fp = fopen(genbuf, "r"))
               		{
				for (i=0;i<gifnum;i++) fgets(genbuf,255,fp);
				sscanf(genbuf,"%s",location);
                 		fclose(fp);
				cgiHeaderLocation(location);
               		} else
               		{
                 	 	cgiHeaderContentType("text/html");
                    		fprintf(cgiOut,"S%sɮ",genbuf);
               		}
		}
		else //Xgif
	        {	
               	  sprintf(genbuf,GIFHOME "/%03d.gif",gifnum);
                 	cgiHeaderContentType("image/gif");
               		if (fp = fopen(genbuf, "r"))
               		{
                 		while (i=fread(genbuf,1,4096, fp)) 
				fwrite(genbuf,1,i,cgiOut);
                 		fclose(fp);
               		} else
               		{
                    		fprintf(cgiOut,"S%sɮ",genbuf);
               		}
		}
               
}
